#!/usr/bin/python3

import argparse
import gitlab
import os
import time

parser = argparse.ArgumentParser(description='Create GitLab Merge Request')
parser.add_argument('title', action='store',
                    help='The title of the MR')
parser.add_argument('--project', '-p', action='store',
                    help='namespace/projectname or project ID')
parser.add_argument('--source-project', action='store', default=None,
                    help='namespace/projectname or source project ID')
parser.add_argument('--destination-branch', action='store', default='main',
                    help='Destination branch')
parser.add_argument('--source-branch', action='store', default='develop',
                    help='Source branch')
parser.add_argument('--description', '-d', action='store', default=None,
                    help='Description')
parser.add_argument('--assign', '-a', action='store', default=None,
                    help='User name to whom this should be assigned')
parser.add_argument('--label', '-l', action='store', default=None,
                    help='Labels, separated by comma')
parser.add_argument('--merge', action='store_true', default=False,
                    help='Auto merge when pipeline succceds')
args = parser.parse_args()

g = gitlab.Gitlab.from_config('lakedrops', [os.path.expanduser('~/.gitlab.cfg')])  # type: gitlab
g.auth()

if args.source_project:
    destination_project = g.projects.get(args.project)
    project = g.projects.get(args.source_project)  # type: gitlab.Project
else:
    destination_project = None
    project = g.projects.get(args.project)  # type: gitlab.Project

if not project:
    exit(1)

arguments = {"title": args.title,
             'source_branch': args.source_branch,
             'target_branch': args.destination_branch
             }
if destination_project:
    arguments['destination_project'] = destination_project.id
if args.description:
    arguments['description'] = args.description
if args.label:
    arguments['label'] = ','.split(args.label)
if args.assign:
    assignee = g.users.list(username=args.assign)[0]
    if assignee:
        arguments['assignee_id'] = assignee.id

mr = project.mergerequests.create(arguments)  # type: gitlab.ProjectMergeRequest
if args.merge:
    time.sleep(5)
    mr.merge()
print(mr.web_url)
